@@ -6,23 +6,13 @@
  * Date        : 2018-12-31
  * Description : digiKam plugin main dialog
  *
- * Copyright (C) 2018-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DPLUGIN_DIALOG_H
-#define DIGIKAM_DPLUGIN_DIALOG_H
+#pragma once
 
 // Qt includes
 
@@ -49,26 +39,22 @@ public:
 
     void setPlugin(DPlugin* const tool);
 
-protected:
-
-    void restoreDialogSize();
-    void saveDialogSize();
-
 private Q_SLOTS:
 
     void slotAboutPlugin();
+    void slotOnlineHandbook();
 
 protected:
 
-    QDialogButtonBox* m_buttons;
+    void showEvent(QShowEvent*) override;
+
+    QDialogButtonBox* m_buttons = nullptr;
 
 private:
 
-    DPlugin*          m_tool;
+    DPlugin*          m_tool    = nullptr;
 
     Q_DISABLE_COPY(DPluginDialog)
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DPLUGIN_DIALOG_H
